
%--  Calculate the elasticity of the contact wire

d = zeros(NDOF);
force = eye(NDOF);
kk = zeros(1,NDOF);
kk1 = kk;

for i = 1:2:NOFN
    d(:,i) = KG(1:end-2,1:end-2)\force(:,i);
    kk(1,i) = force(i,i)/d(i,i);
    kk1(1,i) = d(i,i)/force(i,i);
end

kk1 = kk1*1e3;

%-- Uniformity and max value of elasticity

e_uniformity = (max(kk1(321:2:481))-min(kk1(321:2:481)))/(max(kk1(321:2:481))+min(kk1(321:2:481)))*100
e_max = max(kk1(321:2:481))

%-- Measured values at the reference span

xpos = 80+[0 0.872 1.989 5.172 9.232 12.245 16.371 19.88 23.47 27.241...
    30.584 33.409 37.809 38.868 39.868];
e = [0.166667 0.266667 0.266667 0.416667 0.416667 0.783333 0.81667 0.9...
    0.783333 0.783333 0.566667 0.5333333 0.283333 0.166667 0.4375];

%-- Plot up the elasticy curves

figure('Units','pixels','Position',[100 100 500 375]);
hold on;

hmodel = line(x(161:241),kk1(321:2:481));
hmeasured = line(xpos,e);

set(hmodel,'Linewidth',1.5)
set(hmeasured,'Linestyle','--','Linewidth',1.5)

hXLabel = xlabel('Location [m]');
hYLabel = ylabel('Elasticity [mm/N]');

hLegend = legend([hmodel, hmeasured],'Modelled elasticity','Measured elasticity','Location','best');

set([hLegend,gca],'FontSize',10,'FontName','Times New Roman');
set([hXLabel,hYLabel],'FontSize',12,'FontName','Times New Roman');
set(gca,'FontName','Times New Roman');

set(gca,'Box','off','TickDir','out','TickLength',[.02 .02],...
    'XMinorTick','on','YMinorTick','on','YGrid','on','XColor',...
    [.3 .3 .3],'YColor',[.3 .3 .3],'LineWidth',1);
