%
% m-file:      CatenaryResponse.m
%
% Purpose:     Time integration of the system
%
% Written by:  Arnar Kari Hallgrimsson, Spring 2013
%

function [P,Dall,D_dyn,count,xp,t] =  Newmarkint(MG,CG,KG,dt,Tpass,F0,NOFN,NDOF,N,D_stat,vel,L_TOT,L_EL,kc)

gamma = 0.5;                %Constants can be changed to change between
beta = 0.25;                %methods, gamma=0.5 and beta=0.25 means that 
                            %average acceleration method is used
t = 0:dt:(Tpass+0.25);      %Time vector needs to reach just above the time the train passes Tpass, 0,25 is randomly chosen
NM = length(CG);
D_dyn = zeros(NM,length(t)); 
Ddot_dyn = D_dyn; 
Dddot_dyn = D_dyn;
Dall = D_dyn; 
P = zeros(1,length(t)); 
xp = P; 
F = zeros(NM,length(t));

%These values are all for initial configuartion before integration is
%carried out
U1 = 17;                    %Friction force of the pantograph
F(end,:) = F0;
F(NOFN+1,:) = -N(2);
F(NDOF-2,:) = N(2);
Dall(:,1) = D_stat; 
Dall(end-1,1) = D_stat(1,1);
Dall(end,1) = D_stat(1,1)-0.6; 


ttemp = 0:vel*dt:L_TOT;
xp(1:length(ttemp)) = ttemp;
eta1 = xp(1,2)/L_EL;
F(1:4,1) = [F0 0 0 0]; F(end-1,1) = -F0;
F(1:4,2) = F0.*[1-eta1 0 eta1 0]; F(end-1,2) = -F0;
P(1,1) = F0;
count = 0;

khat = KG+(gamma/(beta*dt))*CG+MG/(beta*dt^2);
a = MG/(beta*dt)+(gamma/beta)*CG;
b = MG/(2*beta)+dt*(gamma/(2*beta)-1)*CG;

%--- Incrementation ---

for i = 1:length(t)-1  
    
    if D_dyn(end,i)>0
        F(end,i+1) = F0-U1; 
    else
        F(end,i+1) = F0+U1;
    end
    
    dphat = F(:,i+1)-F(:,i)+a*Ddot_dyn(:,i)+b*Dddot_dyn(:,i);
    dD_dyn = khat\dphat;
    dDdot_dyn = (gamma/(beta*dt))*dD_dyn-(gamma/beta)*Ddot_dyn(:,i)+...
        dt*(1-gamma/(2*beta))*Dddot_dyn(:,i);
    dDddot_dyn = (1/(beta*dt^2))*dD_dyn-1/(beta*dt)*Ddot_dyn(:,i)-...
        1/(2*beta)*Dddot_dyn(:,i);
    D_dyn(:,i+1) = D_dyn(:,i)+dD_dyn;
    Ddot_dyn(:,i+1) = Ddot_dyn(:,i)+dDdot_dyn;
    Dddot_dyn(:,i+1) = Dddot_dyn(:,i)+dDddot_dyn;
    Dall(:,i+1) = D_dyn(:,i+1)+D_stat;
    
    if xp(1,i+1) ~= 0
        NOEL = floor(xp(1,i)/L_EL+1);
        eta = (xp(1,i)-L_EL*(NOEL-1));
        N1 = 1-3*eta^2/L_EL^2+2*eta^3/L_EL^3;
        N2 = eta-2*eta^2/L_EL+eta^3/L_EL;
        N3 = 3*eta^2/L_EL^2-2*eta^3/L_EL^3;
        N4 = -eta^2/L_EL+eta^3/L_EL^2;
        NSH = [N1 N2 N3 N4];
    
            if NSH*Dall(2*NOEL-1:2*NOEL+2,i+1) > Dall(end-1,i+1)
                P(1,i+1) = 0;
                count = count+1;
                continue
            else
                P(1,i+1) = kc*abs(NSH*Dall(2*NOEL-1:2*NOEL+2,i+1)-Dall(end-1,i+1));
                F(2*NOEL-1:2*NOEL+2,i+1) = P(1,i+1)*NSH';
                F(end-1,i+1) = -P(1,i+1);
                
                
                dphat = F(:,i+1)-F(:,i)+a*Ddot_dyn(:,i)+b*Dddot_dyn(:,i);
                dD_dyn = khat\dphat;
                dDdot_dyn = (gamma/(beta*dt))*dD_dyn-(gamma/beta)*Ddot_dyn(:,i)+...
                dt*(1-gamma/(2*beta))*Dddot_dyn(:,i);
                dDddot_dyn = (1/(beta*dt^2))*dD_dyn-1/(beta*dt)*Ddot_dyn(:,i)-...
                1/(2*beta)*Dddot_dyn(:,i);
                D_dyn(:,i+1) = D_dyn(:,i)+dD_dyn;
                Ddot_dyn(:,i+1) = Ddot_dyn(:,i)+dDdot_dyn;
                Dddot_dyn(:,i+1) = Dddot_dyn(:,i)+dDddot_dyn;
                Dall(:,i+1) = D_dyn(:,i+1)+D_stat;
            end
       
    else
        F(:,i) = 0;
        F(NOFN+1,i) = -N(2);
        F(NDOF-2,i) = N(2);
    end
        
end