
%-- Calculates the vertical displacements of the pantograph using shape
%-- functions

i = 0;
xp = 0;
vp = zeros(round(L_TOT/(vel*dt))+1,1);

while xp <= L_TOT
    i = i+1;
    NOEL = floor(xp/L_EL+1);
    eta = (xp-L_EL*(NOEL-1));
    N1 = 1-3*eta^2/L_EL^2+2*eta^3/L_EL^3;
    N2 = eta-2*eta^2/L_EL+eta^3/L_EL;
    N3 = 3*eta^2/L_EL^2-2*eta^3/L_EL^3;
    N4 = -eta^2/L_EL+eta^3/L_EL^2;
    NSH = [N1 N2 N3 N4];
    vp(i,1) = NSH*Dall(2*NOEL-1:2*NOEL+2,i);
    xp = xp+vel*dt;
end

xp = 0:vel*dt:L_TOT;

trainhit = (80/vel)/dt+1;   %Train hits x=80m
trainhit2 = (120/vel)/dt+1; %Train hits x=120m

%-- Plot up vertical displacements of pantograph and accompanying contact
%-- wire points

figure('Units','pixels','Position',[100 100 500 375]);
hold on;

hpanto = line(xp(1,trainhit:trainhit2),vp(trainhit:trainhit2,1));
hwire = line(xp(1,trainhit:trainhit2),Dall(end-1,trainhit:trainhit2));
set(hwire,'Linewidth',1.5,'Color','r');
set(hpanto,'Linewidth',1.5);

hLegend = legend([hpanto hwire],'Pantograph','Contact wire');
hXLabel = xlabel('Location [m]');
hYLabel = ylabel('Vertical displacement [m]');
set([hLegend, gca]             , ...
    'FontSize'   , 8           );
set([hXLabel,hYLabel],'FontSize',12,'FontName','Times New Roman');
set(gca,'FontName','Times New Roman');
set(gca,'Box','off','TickDir','out','TickLength',[.02 .02],...
    'XMinorTick','on','YMinorTick','on','YGrid','on','XColor',...
    [.3 .3 .3],'YColor',[.3 .3 .3],'LineWidth',1);