%
% m-file:      CatenaryResponse.m
%
% Purpose:     Assembles global damping matrix using Rayleigh damping
%
% Written by:  Arnar Kari Hallgrimsson, Spring 2013
%

function [CG] = Rayleighdamping(omeg,xi,MC,KC,n_dropp,n_dropp1,...
    DROPP_C,NOFN,NDOF)

%--- Coefficients for Rayleigh damping ---

a0_CW = 2*omeg(1)*omeg(2)*(xi(1)*omeg(2)-xi(1)*omeg(1))/(omeg(2)^2-omeg(1)^2);
a1_CW = 2*(xi(1)*omeg(2)-xi(1)*omeg(1))/(omeg(2)^2-omeg(1)^2);

a0_MW = 2*omeg(1)*omeg(2)*(xi(2)*omeg(2)-xi(2)*omeg(1))/(omeg(2)^2-omeg(1)^2);
a1_MW = 2*(xi(2)*omeg(2)-xi(2)*omeg(1))/(omeg(2)^2-omeg(1)^2);

CG(1:NOFN,1:NOFN) = a0_CW*MC(1:NOFN,1:NOFN)+a1_CW*KC(1:NOFN,1:NOFN);
CG(NOFN+1:NDOF,NOFN+1:NDOF) = a0_MW*MC(NOFN+1:NDOF,NOFN+1:NDOF)+...
    a1_MW*KC(NOFN+1:NDOF,NOFN+1:NDOF);

%--- Add damping from droppers ---

for i = 1:length(n_dropp)
    CG(n_dropp(i),n_dropp(i)) = CG(n_dropp(i),n_dropp(i))+DROPP_C;
    CG(n_dropp(i),n_dropp1(i)) = -DROPP_C;
    CG(n_dropp1(i),n_dropp(i)) = -DROPP_C;
    CG(n_dropp1(i),n_dropp1(i)) = CG(n_dropp1(i),n_dropp1(i))+DROPP_C;
end