function [KG,MG,FG] = assembleCat(L_EL,EI,N,RHO,NOE,NOFN,y,E,A,NDOF,g)

%--- Numbering of elements and nodes ---

m = zeros(1,NOE/2);
ni = zeros(1,NOE/2);
nj = zeros(1,NOE/2);
md = zeros(1,NOE/2);

for i = 1:NOE/2
    m(i) = i;
    ni(i) = i;
    nj(i) = i+1;
    md(i) = i+NOE/2;
end

% NEL = [m md];

% GLOBAL MATRICES (STIFFNESS, MASS and DAMPING)

%--- Consistent mass and stiffness matrices -------------------------------

KG = zeros(NDOF);
MG = zeros(NDOF);
FG = zeros(NDOF,1);

KG_CW = zeros(NOFN);
MG_CW = zeros(NOFN);

%--- Consistent matrices for contact wire (cw) ---

for i = 1:max(m);
    
    %--- Element matrices ---
    
    Ke =[12 6*L_EL -12 6*L_EL;6*L_EL 4*L_EL^2 -6*L_EL 2*L_EL^2;-12 ...
        -6*L_EL 12 -6*L_EL;6*L_EL 2*L_EL^2 -6*L_EL 4*L_EL^2];
    Kg = [36 3*L_EL -36 3*L_EL;3*L_EL 4*L_EL^2 -3*L_EL -L_EL^2;-36 ...
        -3*L_EL 36 -3*L_EL;3*L_EL -L_EL^2 -3*L_EL 4*L_EL^2];
    Me = [156 22*L_EL 54 -13*L_EL;22*L_EL 4*L_EL^2 13*L_EL -3*L_EL^2;...
        54 13*L_EL 156 -22*L_EL;-13*L_EL -3*L_EL^2 -22*L_EL 4*L_EL^2];
    
    %--- Connectivity matrix ---
    
    a1=zeros(4,NOFN);
        a1(1,min(nj(i),ni(i))*2-1)=1;
        a1(2,min(nj(i),ni(i))*2)=1;
        a1(3,max(nj(i),ni(i))*2-1)=1;
        a1(4,max(nj(i),ni(i))*2)=1;
        
        a1 = sparse(a1);
    
    Ke = a1'*Ke*a1;
    Kg = a1'*Kg*a1;
    Me = a1'*Me*a1;
    
    fe = [RHO(1)*g*L_EL/2 RHO(1)*g*L_EL/12 RHO(1)*g*L_EL/2 -RHO(1)*g*L_EL/12]';
    
    Ke = (EI(1)/L_EL^3)*Ke;
    Kg = (N(1)/(30*L_EL))*Kg;
    Me = (RHO(1)*L_EL/420)*Me;
    
    
    KG_CW = KG_CW+Ke-Kg;
    MG_CW = MG_CW+Me;
    FG(4*i-3:4*i) = fe;
end

KG(1:NOFN,1:NOFN) = KG_CW;
MG(1:NOFN,1:NOFN) = MG_CW;

%--- Consistent matrices for messenger wire ---

KG_MW = zeros(NOFN/2*3);
MG_MW = zeros(NOFN/2*3);
FG_MW = zeros(NOFN/2*3,1);
y_MW = y(end/2+1:end);

for i = 1:max(m);
    
    X1 = A(2)*E(2)/L_EL;
    Y1 = 12*EI(2)/L_EL^3;
    Y2 = 6*EI(2)/L_EL^2;
    Y3 = 4*EI(2)/L_EL;
    Y4 = 2*EI(2)/L_EL;
    aa = L_EL/2;
   
    %--- Element matrices ---

    Ke =[X1 0 0 -X1 0 0;0 Y1 Y2 0 -Y1 Y2;0 Y2 Y3 0 -Y2 Y4;
        -X1 0 0 X1 0 0;0 -Y1 -Y2 0 Y1 -Y2;0 Y2 Y4 0 -Y2 Y3];
        
    Kg = [0 0 0 0 0 0;
        0 36 3*L_EL 0 -36 3*L_EL;
        0 3*L_EL 4*L_EL^2 0 -3*L_EL -L_EL^2;
        0 0 0 0 0 0;
        0 -36 -3*L_EL 0 36 -3*L_EL;
        0 3*L_EL -L_EL^2 0 -3*L_EL 4*L_EL^2];
    
    Kel = Ke-Kg;
    
    Me = [70 0 0 35 0 0;0 78 22*aa 0 27 -13*aa; 0 22*aa 8*aa^2 0 13*aa -6*aa^2;
        35 0 0 70 0 0;0 27 13*aa 0 78 -22*aa;0 -13*aa -6*aa^2 0 -22*aa 8*aa^2];
    
    fe = [-N(2) RHO(2)*g*L_EL/2 RHO(2)*g*L_EL/12 N(2) RHO(2)*g*L_EL/2 -RHO(2)*g*L_EL/12]';
    
    Kg = (N(2)/(30*L_EL))*Kg;       %Element geometrical stiffness matrix
    Me = (RHO(2)*aa/105)*Me;      %Element mass matrix
    
    
    %--- Connectivity matrix ---
    
    a1 = zeros(6,NOFN/2*3);
        a1(1,min(nj(i),ni(i))*3-2)=1;
        a1(2,min(nj(i),ni(i))*3-1)=1;
        a1(3,min(nj(i),ni(i))*3)=1;
        a1(4,max(nj(i),ni(i))*3-2)=1;
        a1(5,max(nj(i),ni(i))*3-1)=1;
        a1(6,max(nj(i),ni(i))*3)=1;
        
    a1 = sparse(a1);    
    Ke = a1'*Ke*a1;
    Kg = a1'*Kg*a1;
    Me = a1'*Me*a1;
    
    KG_MW = KG_MW+Ke-Kg;
    MG_MW = MG_MW+Me;
    FG_MW(6*i-5:6*i) = fe;
end

%--- Adding the MW matrices into the the system matrices ---
FG((NOFN+1):end) = FG_MW(1:(NDOF-NOFN));
KG(NOFN+1:end,NOFN+1:end) = KG_MW;
MG(NOFN+1:end,NOFN+1:end) = MG_MW;
